@@ -4,14 +4,13 @@ import os
 
 
 class LoadLibraryHandler(AbstractCommandHandler):
-    loaded_library = 0
 
     def __init__(self):
-        pass
+        self._required_parameters_count = 1
 
     def process(self, command):
         try:
-            if len(command.payload) != 1:
+            if len(command.payload) != self._required_parameters_count:
                 raise Exception("LoadLibrary payload parameters mismatch")
 
             if os.path.isdir(command.payload[0]):
